componenttools.all_are_contiguous_components_in_same_parent
===========================================================

.. autofunction:: abjad.tools.componenttools.all_are_contiguous_components_in_same_parent.all_are_contiguous_components_in_same_parent
